@@ -1,7 +1,7 @@
 package App::xsum;
 
 our $DATE = '2019-09-12'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,7 +103,14 @@ _
             'x.doc.show_result' => 0,
         },
         {
-            summary => 'Compute MD5 digests for some files (same as previous example)',
+            summary => 'Compute MD5 digests for some files (same as previous example, -a defaults to "md5")',
+            src => 'xsum *.dat',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Compute MD5 digests for some files (also same as previous example)',
             src => 'xsum -a Digest -A MD5 *.dat',
             src_plang => 'bash',
             test => 0,
@@ -132,21 +139,21 @@ _
         },
         {
             summary => 'Check MD5 digests of files listed in MD5SUMS',
-            src => 'xsum --check -a md5 MD5SUMS',
+            src => 'xsum --check MD5SUMS',
             src_plang => 'bash',
             test => 0,
             'x.doc.show_result' => 0,
         },
         {
             summary => 'Check MD5 digest of one file',
-            src => 'xsum -a md5 download.exe -C 9f4b2277f50a412e56de6e0306f4afb8',
+            src => 'xsum download.exe -C 9f4b2277f50a412e56de6e0306f4afb8',
             src_plang => 'bash',
             test => 0,
             'x.doc.show_result' => 0,
         },
         {
             summary => 'Check MD5 digest of two files',
-            src => 'xsum -a md5 download1.exe -C 9f4b2277f50a412e56de6e0306f4afb8 download2.zip -C 62b3bf86abdfdd87e9f6a3ea7b51aa7b',
+            src => 'xsum download1.exe -C 9f4b2277f50a412e56de6e0306f4afb8 download2.zip -C 62b3bf86abdfdd87e9f6a3ea7b51aa7b',
             src_plang => 'bash',
             test => 0,
             'x.doc.show_result' => 0,
@@ -268,7 +275,7 @@ App::xsum - Compute and check file checksums/digests (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.005 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
+This document describes version 0.006 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
 
 =head1 SYNOPSIS
 
